--- title: "wallaroo.workspace" type: docs linkTitle: "wallaroo.workspace" ---
class Workspace(wallaroo.object.Object):

Workspace provides a user and visibility context for access to models and pipelines.

Workspace( client: Optional[wallaroo.client.Client], data: Dict[str, Any], standalone=False)

Base constructor.

Each object requires:

- a GraphQL client - in order to fill its missing members dynamically
- an initial data blob - typically from unserialized JSON, contains at
- least the data for required members (typically the object's primary key) and optionally other data members.

def to_json(self):
def id(self) -> int:
def name(*args, **kwargs):
def archived(*args, **kwargs):
def created_at(*args, **kwargs):
def created_by(*args, **kwargs):
def models(*args, **kwargs):

Returns a List of Models objects that have been created in this workspace.

def pipelines(*args, **kwargs):
def users(*args, **kwargs):
def add_user(self, user_email: str) -> wallaroo.workspace.Workspace:

Add a user to workspace as participant

def add_owner(self, user_email: str) -> wallaroo.workspace.Workspace:

Add a user to workspace as owner

def remove_user(self, user_email: str):
def list_connections(self) -> wallaroo.connection.ConnectionList:

Return a list of Connections available in this Workspace.

###### Returns

> List of Connections in this Workspace.

def add_connection(self, name: str):

Adds an existing Connection with the given name to this Workspace.

def remove_connection(self, name: str):

Removes a Connection with the given name from this Workspace.

class Workspaces(typing.List[wallaroo.workspace.Workspace]):

Wraps a list of workspaces for display.

##### Inherited Members

builtins.list
  list
  clear
  copy
  append
  insert
  extend
  pop
  remove
  index
  count
  reverse
  sort